pub struct EnumProperty<T: PropertyEnum + 'static> {
pub name: &'static str,
pub possible_values: &'static [T],
comparison_values: &'static [T],
}Fields
name: &'static strpossible_values: &'static [T]comparison_values: &'static [T]Implementations
Sourceimpl<T: PropertyEnum> EnumProperty<T>
impl<T: PropertyEnum> EnumProperty<T>
Sourcepub const fn new(name: &'static str, possible_values: &'static [T]) -> Self
pub const fn new(name: &'static str, possible_values: &'static [T]) -> Self
Creates an enum property whose state and natural comparison orders match.
Sourcepub const fn with_comparison_order(
name: &'static str,
possible_values: &'static [T],
comparison_values: &'static [T],
) -> Self
pub const fn with_comparison_order( name: &'static str, possible_values: &'static [T], comparison_values: &'static [T], ) -> Self
Creates a property whose state order differs from the enum’s natural order.
comparison_values must contain every possible value in the order used
by the Vanilla enum’s Comparable implementation.
pub const fn value_count(&self) -> usize
Sourceimpl<T: PartialEq + PropertyEnum + 'static> EnumProperty<T>
impl<T: PartialEq + PropertyEnum + 'static> EnumProperty<T>
pub const fn get_internal_index_const(&self, value: &T) -> usize